@@ -27,7 +27,7 @@ gi.require_version("Adw", "1")
 
 from gi.repository import Adw, Gio
 
-from .window import MorphosisWindow
+from morphosis.window import MorphosisWindow
 
 
 class MorphosisApplication(Adw.Application):
@@ -40,20 +40,19 @@ class MorphosisApplication(Adw.Application):
         )
 
         # TODO: Move relevant actions to MorphosisWindow
-        self.__create_action("quit", lambda *_: self.quit(), ("<primary>q",))
-        self.__create_action(
+        self._create_action("quit", lambda *_: self.quit(), ("<primary>q",))
+        self._create_action(
             "close",
             lambda *_: window.close() if (window := self.get_active_window()) else None,
             ("<primary>w",),
         )
-        self.__create_action("about", self.__on_about_action)
+        self._create_action("about", self._on_about_action)
 
     def do_activate(self) -> None:
         """Raise or create the app's main window."""
         (self.get_active_window() or MorphosisWindow(application=self)).present()
 
-    def __on_about_action(self, *_args: Any) -> None:
-        """Create and present the about dialog."""
+    def _on_about_action(self, *_args: Any) -> None:
         about = Adw.AboutDialog.new_from_appdata(
             "/garden/jamie/Morphosis/garden.jamie.Morphosis.metainfo.xml"
         )
@@ -71,8 +70,11 @@ class MorphosisApplication(Adw.Application):
         about.set_copyright("© 2024 Jamie Gravendeel")
         about.present(self.get_active_window())
 
-    def __create_action(
-        self, name: str, callback: Callable[..., None], shortcuts: tuple[str] = None
+    def _create_action(
+        self,
+        name: str,
+        callback: Callable[..., None],
+        shortcuts: tuple[str] | None = None,
     ) -> None:
         """Add an application action."""
         action = Gio.SimpleAction.new(name, None)
