@@ -38,8 +38,8 @@ class MorphosisWindow(Adw.ApplicationWindow):
     toast_overlay: Adw.ToastOverlay = Gtk.Template.Child()
     navigation_view: Adw.NavigationView = Gtk.Template.Child()
 
-    format_row: Adw.ActionRow = Gtk.Template.Child()
-    font_style_row: Adw.ActionRow = Gtk.Template.Child()
+    format_row: Adw.ComboRow = Gtk.Template.Child()
+    font_style_row: Adw.ComboRow = Gtk.Template.Child()
 
     has_font_options = GObject.Property(type=bool, default=False)
 
@@ -64,7 +64,7 @@ class MorphosisWindow(Adw.ApplicationWindow):
             Gio.SettingsBindFlags.DEFAULT,
         )
 
-        self.document.connect("convert-finished", self.__on_convert_finished)
+        self.document.connect("convert-finished", self._on_convert_finished)
         self.document.connect(
             "invalid-content-type",
             lambda *_: self.toast_overlay.add_toast(
@@ -135,7 +135,7 @@ class MorphosisWindow(Adw.ApplicationWindow):
 
         dialog.save(self, callback=save_document_cb)
 
-    def __on_convert_finished(
+    def _on_convert_finished(
         self,
         _obj: Any,
         output_file: Gio.File | None = None,
